@@ -1,4 +1,4 @@
-# $Id: Item.pm 11992 2006-01-16 18:59:58Z wsnyder $
+# $Id: Item.pm 15713 2006-03-13 17:42:48Z wsnyder $
 ######################################################################
 #
 # Copyright 2001-2006 by Wilson Snyder.  This program is free software;
@@ -21,7 +21,7 @@ use vars qw($VERSION $Debug $AUTOLOAD);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '1.250';
+$VERSION = '1.260';
 
 our %Keys =
     (#     sorted by compressed----v
@@ -32,7 +32,7 @@ our %Keys =
      "column"	 => { compressed=>"n", default=>'0'},
      "comment"	 => { compressed=>"o", default=>'""',},
      "type"	 => { compressed=>"t", default=>'""',},
-     "threash"	 => { compressed=>"s", default=>'undef',},
+     "thresh"	 => { compressed=>"s", default=>'undef',},
      );
 
 our %DecompressKey;
